@@ -18,6 +18,7 @@ import re
 import shutil
 import stat
 import subprocess
+import time
 
 import flask
 import jinja2
@@ -35,11 +36,11 @@ from octavia.common import utils as octavia_utils
 
 LOG = logging.getLogger(__name__)
 BUFFER = 100
+HAPROXY_RELOAD_RETRIES = 3
+HAPROXY_QUERY_RETRIES = 5
 
 CONF = cfg.CONF
 
-UPSTART_CONF = 'upstart.conf.j2'
-SYSVINIT_CONF = 'sysvinit.conf.j2'
 SYSTEMD_CONF = 'systemd.conf.j2'
 
 JINJA_ENV = jinja2.Environment(
@@ -47,13 +48,11 @@ JINJA_ENV = jinja2.Environment(
     loader=jinja2.FileSystemLoader(os.path.dirname(
         os.path.realpath(__file__)
     ) + consts.AGENT_API_TEMPLATES))
-UPSTART_TEMPLATE = JINJA_ENV.get_template(UPSTART_CONF)
-SYSVINIT_TEMPLATE = JINJA_ENV.get_template(SYSVINIT_CONF)
 SYSTEMD_TEMPLATE = JINJA_ENV.get_template(SYSTEMD_CONF)
 
 
 # Wrap a stream so we can compute the md5 while reading
-class Wrapped(object):
+class Wrapped:
     def __init__(self, stream_):
         self.stream = stream_
         self.hash = md5(usedforsecurity=False)  # nosec
@@ -71,7 +70,7 @@ class Wrapped(object):
         return getattr(self.stream, attr)
 
 
-class Loadbalancer(object):
+class Loadbalancer:
 
     def get_haproxy_config(self, lb_id):
         """Gets the haproxy config
@@ -79,7 +78,7 @@ class Loadbalancer(object):
         :param listener_id: the id of the listener
         """
         self._check_lb_exists(lb_id)
-        with open(util.config_path(lb_id), 'r', encoding='utf-8') as file:
+        with open(util.config_path(lb_id), encoding='utf-8') as file:
             cfg = file.read()
             resp = webob.Response(cfg, content_type='text/plain')
             resp.headers['ETag'] = (
@@ -126,12 +125,12 @@ class Loadbalancer(object):
             file.write(new_config)
 
         # use haproxy to check the config
-        cmd = "haproxy -c -L {peer} -f {config_file} -f {haproxy_ug}".format(
-            config_file=name, peer=peer_name,
-            haproxy_ug=consts.HAPROXY_USER_GROUP_CFG)
+        cmd = (f"haproxy -c -L {peer_name} -f {name} -f "
+               f"{consts.HAPROXY_USER_GROUP_CFG}")
 
         try:
-            subprocess.check_output(cmd.split(), stderr=subprocess.STDOUT)
+            subprocess.check_output(cmd.split(), stderr=subprocess.STDOUT,
+                                    encoding='utf-8')
         except subprocess.CalledProcessError as e:
             LOG.error("Failed to verify haproxy file: %s %s", e, e.output)
             # Save the last config that failed validation for debugging
@@ -143,43 +142,16 @@ class Loadbalancer(object):
         # file ok - move it
         os.rename(name, util.config_path(lb_id))
 
-        try:
+        init_path = util.init_path(lb_id)
 
-            init_system = util.get_os_init_system()
+        template = SYSTEMD_TEMPLATE
+        # Render and install the network namespace systemd service
+        util.install_netns_systemd_service()
+        util.run_systemctl_command(
+            consts.ENABLE, consts.AMP_NETNS_SVC_PREFIX + '.service', False)
 
-            LOG.debug('Found init system: %s', init_system)
-
-            init_path = util.init_path(lb_id, init_system)
-
-            if init_system == consts.INIT_SYSTEMD:
-                template = SYSTEMD_TEMPLATE
-                # Render and install the network namespace systemd service
-                util.install_netns_systemd_service()
-                util.run_systemctl_command(
-                    consts.ENABLE, consts.AMP_NETNS_SVC_PREFIX + '.service')
-            elif init_system == consts.INIT_UPSTART:
-                template = UPSTART_TEMPLATE
-            elif init_system == consts.INIT_SYSVINIT:
-                template = SYSVINIT_TEMPLATE
-                init_enable_cmd = "insserv {file}".format(file=init_path)
-            else:
-                raise util.UnknownInitError()
-
-        except util.UnknownInitError:
-            LOG.error("Unknown init system found.")
-            return webob.Response(json={
-                'message': "Unknown init system in amphora",
-                'details': "The amphora image is running an unknown init "
-                           "system.  We can't create the init configuration "
-                           "file for the load balancing process."}, status=500)
-
-        if init_system == consts.INIT_SYSTEMD:
-            # mode 00644
-            mode = stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH
-        else:
-            # mode 00755
-            mode = (stat.S_IRWXU | stat.S_IRGRP | stat.S_IXGRP |
-                    stat.S_IROTH | stat.S_IXOTH)
+        # mode 00644
+        mode = stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH
 
         hap_major, hap_minor = haproxy_compatibility.get_haproxy_versions()
         if not os.path.exists(init_path):
@@ -193,9 +165,6 @@ class Loadbalancer(object):
                     haproxy_state_file=util.state_file_path(lb_id),
                     haproxy_socket=util.haproxy_sock_path(lb_id),
                     haproxy_user_group_cfg=consts.HAPROXY_USER_GROUP_CFG,
-                    respawn_count=util.CONF.haproxy_amphora.respawn_count,
-                    respawn_interval=(util.CONF.haproxy_amphora.
-                                      respawn_interval),
                     amphora_netns=consts.AMP_NETNS_SVC_PREFIX,
                     amphora_nsname=consts.AMPHORA_NAMESPACE,
                     haproxy_major_version=hap_major,
@@ -204,26 +173,36 @@ class Loadbalancer(object):
                 text_file.write(text)
 
         # Make sure the new service is enabled on boot
-        if init_system == consts.INIT_SYSTEMD:
+        try:
             util.run_systemctl_command(
-                consts.ENABLE, "haproxy-{lb_id}".format(lb_id=lb_id))
-        elif init_system == consts.INIT_SYSVINIT:
-            try:
-                subprocess.check_output(init_enable_cmd.split(),
-                                        stderr=subprocess.STDOUT)
-            except subprocess.CalledProcessError as e:
-                LOG.error("Failed to enable haproxy-%(lb_id)s service: "
-                          "%(err)s %(out)s", {'lb_id': lb_id, 'err': e,
-                                              'out': e.output})
-                return webob.Response(json={
-                    'message': "Error enabling haproxy-{0} service".format(
-                        lb_id), 'details': e.output}, status=500)
+                consts.ENABLE, consts.LOADBALANCER_SYSTEMD % lb_id)
+        except subprocess.CalledProcessError as e:
+            return webob.Response(json={
+                'message': "Error enabling octavia-keepalived service",
+                'details': e.output}, status=500)
 
         res = webob.Response(json={'message': 'OK'}, status=202)
         res.headers['ETag'] = stream.get_md5()
 
         return res
 
+    def _check_haproxy_uptime(self, lb_id):
+        stat_sock_file = util.haproxy_sock_path(lb_id)
+        lb_query = haproxy_query.HAProxyQuery(stat_sock_file)
+        retries = HAPROXY_QUERY_RETRIES
+        for idx in range(retries):
+            try:
+                info = lb_query.show_info()
+                uptime_sec = info['Uptime_sec']
+            except Exception as e:
+                LOG.warning('Failed to get haproxy info: %s, retrying.', e)
+                time.sleep(1)
+                continue
+            uptime = int(uptime_sec)
+            return uptime
+        LOG.error('Failed to get haproxy uptime after %d tries.', retries)
+        return None
+
     def start_stop_lb(self, lb_id, action):
         action = action.lower()
         if action not in [consts.AMP_ACTION_START,
@@ -231,7 +210,7 @@ class Loadbalancer(object):
                           consts.AMP_ACTION_RELOAD]:
             return webob.Response(json={
                 'message': 'Invalid Request',
-                'details': "Unknown action: {0}".format(action)}, status=400)
+                'details': f"Unknown action: {action}"}, status=400)
 
         self._check_lb_exists(lb_id)
         is_vrrp = (CONF.controller_worker.loadbalancer_topology ==
@@ -257,20 +236,45 @@ class Loadbalancer(object):
                     # failure!
                     LOG.warning('Failed to save haproxy-%s state!', lb_id)
 
-        cmd = ("/usr/sbin/service haproxy-{lb_id} {action}".format(
-            lb_id=lb_id, action=action))
+        retries = (HAPROXY_RELOAD_RETRIES
+                   if action == consts.AMP_ACTION_RELOAD
+                   else 1)
+        saved_exc = None
+        for idx in range(retries):
+            try:
+                util.run_systemctl_command(
+                    action, consts.LOADBALANCER_SYSTEMD % lb_id)
+            except subprocess.CalledProcessError as e:
+                # Mitigation for
+                # https://bugs.launchpad.net/octavia/+bug/2054666
+                if ('is not active, cannot reload.' in e.output and
+                        action == consts.AMP_ACTION_RELOAD):
 
-        try:
-            subprocess.check_output(cmd.split(), stderr=subprocess.STDOUT)
-        except subprocess.CalledProcessError as e:
-            if b'Job is already running' not in e.output:
-                LOG.debug(
-                    "Failed to %(action)s haproxy-%(lb_id)s service: %(err)s "
-                    "%(out)s", {'action': action, 'lb_id': lb_id,
-                                'err': e, 'out': e.output})
-                return webob.Response(json={
-                    'message': "Error {0}ing haproxy".format(action),
-                    'details': e.output}, status=500)
+                    saved_exc = e
+
+                    # Wait a few seconds and check that haproxy was restarted
+                    uptime = self._check_haproxy_uptime(lb_id)
+                    # If haproxy is not reachable or was restarted more than 15
+                    # sec ago, let's retry (or maybe restart?)
+                    if not uptime or uptime > 15:
+                        continue
+                    # haproxy probably crashed and was restarted, log it and
+                    # continue
+                    LOG.warning("An error occured with haproxy while it "
+                                "was reloaded, check the haproxy logs for "
+                                "more details.")
+                    break
+                if 'Job is already running' not in e.output:
+                    return webob.Response(json={
+                        'message': f"Error {action}ing haproxy",
+                        'details': e.output
+                    }, status=500)
+            break
+        else:
+            # no break, we reach the retry limit for reloads
+            return webob.Response(json={
+                'message': f"Error {action}ing haproxy",
+                'details': saved_exc.output}, status=500)
 
         # If we are not in active/standby we need to send an IP
         # advertisement (GARP or NA). Keepalived handles this for
@@ -283,12 +287,10 @@ class Loadbalancer(object):
                       consts.AMP_ACTION_RELOAD]:
             return webob.Response(json={
                 'message': 'OK',
-                'details': 'Listener {lb_id} {action}ed'.format(
-                    lb_id=lb_id, action=action)}, status=202)
+                'details': f'Listener {lb_id} {action}ed'}, status=202)
 
         details = (
-            'Configuration file is valid\n'
-            'haproxy daemon for {0} started'.format(lb_id)
+            f'Configuration file is valid\nhaproxy daemon for {lb_id} started'
         )
 
         return webob.Response(json={'message': 'OK', 'details': details},
@@ -303,9 +305,9 @@ class Loadbalancer(object):
         # check if that haproxy is still running and if stop it
         if os.path.exists(util.pid_path(lb_id)) and os.path.exists(
                 os.path.join('/proc', util.get_haproxy_pid(lb_id))):
-            cmd = "/usr/sbin/service haproxy-{0} stop".format(lb_id)
             try:
-                subprocess.check_output(cmd.split(), stderr=subprocess.STDOUT)
+                util.run_systemctl_command(
+                    consts.STOP, consts.LOADBALANCER_SYSTEMD % lb_id)
             except subprocess.CalledProcessError as e:
                 LOG.error("Failed to stop haproxy-%s service: %s %s",
                           lb_id, e, e.output)
@@ -334,29 +336,10 @@ class Loadbalancer(object):
             pass
 
         # disable the service
-        init_system = util.get_os_init_system()
-        init_path = util.init_path(lb_id, init_system)
+        init_path = util.init_path(lb_id)
 
-        if init_system == consts.INIT_SYSTEMD:
-            util.run_systemctl_command(
-                consts.DISABLE, "haproxy-{lb_id}".format(
-                    lb_id=lb_id))
-        elif init_system == consts.INIT_SYSVINIT:
-            init_disable_cmd = "insserv -r {file}".format(file=init_path)
-        elif init_system != consts.INIT_UPSTART:
-            raise util.UnknownInitError()
-
-        if init_system == consts.INIT_SYSVINIT:
-            try:
-                subprocess.check_output(init_disable_cmd.split(),
-                                        stderr=subprocess.STDOUT)
-            except subprocess.CalledProcessError as e:
-                LOG.error("Failed to disable haproxy-%(lb_id)s service: "
-                          "%(err)s %(out)s", {'lb_id': lb_id, 'err': e,
-                                              'out': e.output})
-                return webob.Response(json={
-                    'message': "Error disabling haproxy-{0} service".format(
-                        lb_id), 'details': e.output}, status=500)
+        util.run_systemctl_command(
+            consts.DISABLE, consts.LOADBALANCER_SYSTEMD % lb_id, False)
 
         # delete the directory + init script for that listener
         shutil.rmtree(util.haproxy_dir(lb_id))
@@ -420,10 +403,10 @@ class Loadbalancer(object):
         if not path_exists:
             return webob.Response(json={
                 'message': 'Certificate Not Found',
-                'details': "No certificate with filename: {f}".format(
-                    f=filename)}, status=404)
+                'details': f"No certificate with filename: {filename}"},
+                status=404)
 
-        with open(cert_path, 'r', encoding='utf-8') as crt_file:
+        with open(cert_path, encoding='utf-8') as crt_file:
             cert = crt_file.read()
             md5sum = md5(octavia_utils.b(cert),
                          usedforsecurity=False).hexdigest()  # nosec
@@ -442,8 +425,7 @@ class Loadbalancer(object):
             if os.path.exists(
                     os.path.join('/proc', util.get_haproxy_pid(lb_id))):
                 # Check if the listener is disabled
-                with open(util.config_path(lb_id),
-                          'r', encoding='utf-8') as file:
+                with open(util.config_path(lb_id), encoding='utf-8') as file:
                     cfg = file.read()
                     m = re.findall('^frontend (.*)$', cfg, re.MULTILINE)
                     return m or []
@@ -458,8 +440,8 @@ class Loadbalancer(object):
             raise exceptions.HTTPException(
                 response=webob.Response(json={
                     'message': 'Loadbalancer Not Found',
-                    'details': "No loadbalancer with UUID: {0}".format(
-                        lb_id)}, status=404))
+                    'details': f"No loadbalancer with UUID: {lb_id}"},
+                    status=404))
 
     def _check_ssl_filename_format(self, filename):
         # check if the format is (xxx.)*xxx.pem
