@@ -14,6 +14,7 @@
 # under the License.
 import functools
 import hashlib
+import json
 import os
 import ssl
 import time
@@ -24,7 +25,6 @@ from oslo_context import context as oslo_context
 from oslo_log import log as logging
 from oslo_utils.secretutils import md5
 import requests
-import simplejson
 from stevedore import driver as stevedore_driver
 
 from octavia.amphorae.driver_exceptions import exceptions as driver_except
@@ -308,7 +308,7 @@ class HaproxyAmphoraLoadBalancerDriver(
         for cert_id in certs_to_delete:
             self.clients[amphora.api_version].delete_cert_pem(
                 amphora, listener.load_balancer.id,
-                '{id}.pem'.format(id=cert_id))
+                f'{cert_id}.pem')
 
         # See how many non-UDP/SCTP listeners we have left
         non_lvs_listener_count = len([
@@ -451,7 +451,7 @@ class HaproxyAmphoraLoadBalancerDriver(
             for cert in certs:
                 pem = cert_parser.build_pem(cert)
                 md5sum = md5(pem, usedforsecurity=False).hexdigest()  # nosec
-                name = '{id}.pem'.format(id=cert.id)
+                name = f'{cert.id}.pem'
                 cert_filename_list.append(
                     os.path.join(
                         CONF.haproxy_amphora.base_cert_dir, obj_id, name))
@@ -460,10 +460,10 @@ class HaproxyAmphoraLoadBalancerDriver(
             if certs:
                 # Build and upload the crt-list file for haproxy
                 crt_list = "\n".join(cert_filename_list)
-                crt_list = f'{crt_list}\n'.encode('utf-8')
+                crt_list = f'{crt_list}\n'.encode()
                 md5sum = md5(crt_list,
                              usedforsecurity=False).hexdigest()  # nosec
-                name = '{id}.pem'.format(id=listener.id)
+                name = f'{listener.id}.pem'
                 self._upload_cert(amphora, obj_id, crt_list, md5sum, name)
         return {'tls_cert': tls_cert, 'sni_certs': sni_certs}
 
@@ -482,7 +482,7 @@ class HaproxyAmphoraLoadBalancerDriver(
             pass
         md5sum = md5(secret, usedforsecurity=False).hexdigest()  # nosec
         id = hashlib.sha1(secret).hexdigest()  # nosec
-        name = '{id}.pem'.format(id=id)
+        name = f'{id}.pem'
 
         if amphora and obj_id:
             self._upload_cert(
@@ -520,7 +520,7 @@ class HaproxyAmphoraLoadBalancerDriver(
             except AttributeError:
                 pass
             md5sum = md5(pem, usedforsecurity=False).hexdigest()  # nosec
-            name = '{id}.pem'.format(id=tls_cert.id)
+            name = f'{tls_cert.id}.pem'
             if amphora and obj_id:
                 self._upload_cert(amphora, obj_id, pem=pem,
                                   md5sum=md5sum, name=name)
@@ -625,11 +625,11 @@ class CustomHostNameCheckingAdapter(requests.adapters.HTTPAdapter):
 
     def init_poolmanager(self, *pool_args, **pool_kwargs):
         proto = CONF.amphora_agent.agent_tls_protocol.replace('.', '_')
-        pool_kwargs['ssl_version'] = getattr(ssl, "PROTOCOL_%s" % proto)
+        pool_kwargs['ssl_version'] = getattr(ssl, f"PROTOCOL_{proto}")
         return super().init_poolmanager(*pool_args, **pool_kwargs)
 
 
-class AmphoraAPIClientBase(object):
+class AmphoraAPIClientBase:
     def __init__(self):
         super().__init__()
 
@@ -646,19 +646,13 @@ class AmphoraAPIClientBase(object):
 
     def _base_url(self, ip, api_version=None):
         if utils.is_ipv6_lla(ip):
-            ip = '[{ip}%{interface}]'.format(
-                ip=ip,
-                interface=CONF.haproxy_amphora.lb_network_interface)
+            ip = f'[{ip}%{CONF.haproxy_amphora.lb_network_interface}]'
         elif utils.is_ipv6(ip):
-            ip = '[{ip}]'.format(ip=ip)
+            ip = f'[{ip}]'
         if api_version:
-            return "https://{ip}:{port}/{version}/".format(
-                ip=ip,
-                port=CONF.haproxy_amphora.bind_port,
-                version=api_version)
-        return "https://{ip}:{port}/".format(
-            ip=ip,
-            port=CONF.haproxy_amphora.bind_port)
+            return (f"https://{ip}:{CONF.haproxy_amphora.bind_port}"
+                    f"/{api_version}/")
+        return f"https://{ip}:{CONF.haproxy_amphora.bind_port}/"
 
     def request(self, method: str, amp: db_models.Amphora, path: str = '/',
                 timeout_dict: Optional[dict] = None,
@@ -723,7 +717,7 @@ class AmphoraAPIClientBase(object):
                         if 'No suitable network interface found' in json_data:
                             LOG.debug("Amphora network interface not found.")
                             raise requests.ConnectionError
-                    except simplejson.JSONDecodeError:  # if r.json() fails
+                    except json.JSONDecodeError:  # if r.json() fails
                         pass  # TODO(rm_work) Should we do something?
                 return r
             except (requests.ConnectionError, requests.Timeout) as e:
@@ -774,31 +768,28 @@ class AmphoraAPIClient1_0(AmphoraAPIClientBase):
     def upload_config(self, amp, loadbalancer_id, config, timeout_dict=None):
         r = self.put(
             amp,
-            'loadbalancer/{amphora_id}/{loadbalancer_id}/haproxy'.format(
-                amphora_id=amp.id, loadbalancer_id=loadbalancer_id),
+            f'loadbalancer/{amp.id}/{loadbalancer_id}/haproxy',
             timeout_dict, data=config)
         return exc.check_exception(r)
 
     def get_listener_status(self, amp, listener_id):
         r = self.get(
             amp,
-            'listeners/{listener_id}'.format(listener_id=listener_id))
+            f'listeners/{listener_id}')
         if exc.check_exception(r):
             return r.json()
         return None
 
     def _action(self, action, amp, object_id, timeout_dict=None):
         r = self.put(
-            amp, 'loadbalancer/{object_id}/{action}'.format(
-                object_id=object_id, action=action),
+            amp, f'loadbalancer/{object_id}/{action}',
             timeout_dict=timeout_dict)
         return exc.check_exception(r)
 
     def upload_cert_pem(self, amp, loadbalancer_id, pem_filename, pem_file):
         r = self.put(
             amp,
-            'loadbalancer/{loadbalancer_id}/certificates/{filename}'.format(
-                loadbalancer_id=loadbalancer_id, filename=pem_filename),
+            f'loadbalancer/{loadbalancer_id}/certificates/{pem_filename}',
             data=pem_file)
         return exc.check_exception(r)
 
@@ -806,8 +797,7 @@ class AmphoraAPIClient1_0(AmphoraAPIClientBase):
                         ignore=tuple()):
         r = self.get(
             amp,
-            'loadbalancer/{loadbalancer_id}/certificates/{filename}'.format(
-                loadbalancer_id=loadbalancer_id, filename=pem_filename))
+            f'loadbalancer/{loadbalancer_id}/certificates/{pem_filename}')
         if exc.check_exception(r, ignore):
             return r.json().get("md5sum")
         return None
@@ -815,8 +805,7 @@ class AmphoraAPIClient1_0(AmphoraAPIClientBase):
     def delete_cert_pem(self, amp, loadbalancer_id, pem_filename):
         r = self.delete(
             amp,
-            'loadbalancer/{loadbalancer_id}/certificates/{filename}'.format(
-                loadbalancer_id=loadbalancer_id, filename=pem_filename))
+            f'loadbalancer/{loadbalancer_id}/certificates/{pem_filename}')
         return exc.check_exception(r, (404,))
 
     def update_cert_for_rotation(self, amp, pem_file):
@@ -825,7 +814,7 @@ class AmphoraAPIClient1_0(AmphoraAPIClientBase):
 
     def delete_listener(self, amp, object_id):
         r = self.delete(
-            amp, 'listeners/{object_id}'.format(object_id=object_id))
+            amp, f'listeners/{object_id}')
         return exc.check_exception(r, (404,))
 
     def get_info(self, amp, raise_retry_exception=False,
@@ -855,7 +844,7 @@ class AmphoraAPIClient1_0(AmphoraAPIClientBase):
 
     def plug_vip(self, amp, vip, net_info):
         r = self.post(amp,
-                      'plug/vip/{vip}'.format(vip=vip),
+                      f'plug/vip/{vip}',
                       json=net_info)
         return exc.check_exception(r)
 
@@ -864,12 +853,12 @@ class AmphoraAPIClient1_0(AmphoraAPIClientBase):
         return exc.check_exception(r)
 
     def _vrrp_action(self, action, amp, timeout_dict=None):
-        r = self.put(amp, 'vrrp/{action}'.format(action=action),
+        r = self.put(amp, f'vrrp/{action}',
                      timeout_dict=timeout_dict)
         return exc.check_exception(r)
 
     def get_interface(self, amp, ip_addr, timeout_dict=None, log_error=True):
-        r = self.get(amp, 'interface/{ip_addr}'.format(ip_addr=ip_addr),
+        r = self.get(amp, f'interface/{ip_addr}',
                      timeout_dict=timeout_dict)
         return exc.check_exception(r, log_error=log_error).json()
 
@@ -877,8 +866,7 @@ class AmphoraAPIClient1_0(AmphoraAPIClientBase):
     def upload_udp_config(self, amp, listener_id, config, timeout_dict=None):
         r = self.put(
             amp,
-            'listeners/{amphora_id}/{listener_id}/udp_listener'.format(
-                amphora_id=amp.id, listener_id=listener_id), timeout_dict,
+            f'listeners/{amp.id}/{listener_id}/udp_listener', timeout_dict,
             data=config)
         return exc.check_exception(r)
 
