@@ -31,7 +31,7 @@ NOVA_VERSION = '2.15'
 CINDER_VERSION = '3'
 
 
-class NovaAuth(object):
+class NovaAuth:
     nova_client = None
 
     @classmethod
@@ -70,7 +70,7 @@ class NovaAuth(object):
         return cls.nova_client
 
 
-class NeutronAuth(object):
+class NeutronAuth:
     neutron_client = None
 
     @classmethod
@@ -111,7 +111,6 @@ class NeutronAuth(object):
         client.
         """
         sess = keystone.KeystoneSession('neutron').get_session()
-        kwargs = {}
         neutron_endpoint = CONF.neutron.endpoint_override
         if neutron_endpoint is None:
             endpoint_data = sess.get_endpoint_data(
@@ -120,20 +119,15 @@ class NeutronAuth(object):
                 region_name=CONF.neutron.region_name)
             neutron_endpoint = endpoint_data.catalog_url
 
-        neutron_cafile = getattr(CONF.neutron, "cafile", None)
-        insecure = getattr(CONF.neutron, "insecure", False)
-        kwargs['verify'] = not insecure
-        if neutron_cafile is not None and not insecure:
-            kwargs['verify'] = neutron_cafile
         user_auth = token_endpoint.Token(neutron_endpoint, context.auth_token)
-        user_sess = session.Session(auth=user_auth, **kwargs)
+        user_sess = session.Session(auth=user_auth)
 
         conn = openstack.connection.Connection(
             session=user_sess, oslo_conf=CONF)
         return conn.network
 
 
-class GlanceAuth(object):
+class GlanceAuth:
     glance_client = None
 
     @classmethod
@@ -172,7 +166,7 @@ class GlanceAuth(object):
         return cls.glance_client
 
 
-class CinderAuth(object):
+class CinderAuth:
     cinder_client = None
 
     @classmethod
