@@ -148,14 +148,6 @@ amphora_agent_opts = [
     cfg.StrOpt('agent_server_network_dir',
                help=_("The directory where new network interfaces "
                       "are located")),
-    cfg.StrOpt('agent_server_network_file',
-               help=_("The file where the network interfaces are located. "
-                      "Specifying this will override any value set for "
-                      "agent_server_network_dir."),
-               deprecated_for_removal=True,
-               deprecated_reason=_('New amphora interface management '
-                                   'does not support single interface file.'),
-               deprecated_since='Xena'),
     cfg.IntOpt('agent_request_read_timeout', default=180,
                help=_("The time in seconds to allow a request from the "
                       "controller to run before terminating the socket.")),
@@ -317,13 +309,6 @@ health_manager_opts = [
                default=10,
                mutable=True,
                help=_('Sleep time between sending heartbeats.')),
-
-    # Used for updating health
-    cfg.StrOpt('health_update_driver', default='health_db',
-               help=_('Driver for updating amphora health system.'),
-               deprecated_for_removal=True,
-               deprecated_reason=_('This driver interface was removed.'),
-               deprecated_since='Victoria'),
 ]
 
 oslo_messaging_opts = [
@@ -396,8 +381,14 @@ haproxy_amphora_opts = [
     cfg.StrOpt('haproxy_cmd', default='/usr/sbin/haproxy',
                help=_("The full path to haproxy")),
     cfg.IntOpt('respawn_count', default=2,
+               deprecated_for_removal=True,
+               deprecated_reason='upstart support has been removed and this '
+                                 'option is no longer used.',
                help=_("The respawn count for haproxy's upstart script")),
     cfg.IntOpt('respawn_interval', default=2,
+               deprecated_for_removal=True,
+               deprecated_reason='upstart support has been removed and this '
+                                 'option is no longer used.',
                help=_("The respawn interval for haproxy's upstart script")),
     cfg.FloatOpt('rest_request_conn_timeout', default=10,
                  help=_("The time in seconds to wait for a REST API "
@@ -422,11 +413,6 @@ haproxy_amphora_opts = [
                help=_("The client certificate to talk to the agent")),
     cfg.StrOpt('server_ca', default='/etc/octavia/certs/server_ca.pem',
                help=_("The ca which signed the server certificates")),
-    cfg.BoolOpt('use_upstart', default=True,
-                deprecated_for_removal=True,
-                deprecated_reason='This is now automatically discovered '
-                                  ' and configured.',
-                help=_("If False, use sysvinit.")),
     cfg.IntOpt('api_db_commit_retry_attempts', default=15,
                help=_('The number of times the database action will be '
                       'attempted.')),
@@ -507,9 +493,6 @@ controller_worker_opts = [
                default='distributor_noop_driver',
                help=_('Name of the distributor driver to use')),
     cfg.ListOpt('statistics_drivers', default=['stats_db'],
-                deprecated_name='stats_update_driver',
-                deprecated_group='health_manager',
-                deprecated_since='Victoria',
                 help=_('List of drivers for updating amphora statistics.')),
     cfg.StrOpt('loadbalancer_topology',
                default=constants.TOPOLOGY_SINGLE,
@@ -588,6 +571,10 @@ task_flow_opts = [
                     'job id and claims for it.'),
     cfg.StrOpt('jobboard_redis_sentinel', default=None,
                help='Sentinel name if it is used for Redis.'),
+    cfg.StrOpt('jobboard_redis_sentinel_username',
+               help='Redis Sentinel server user name'),
+    cfg.StrOpt('jobboard_redis_sentinel_password', secret=True,
+               help='Redis Sentinel server password'),
     cfg.DictOpt('jobboard_redis_backend_ssl_options',
                 help='Redis jobboard backend ssl configuration options.',
                 default={'ssl': False,
@@ -595,6 +582,13 @@ task_flow_opts = [
                          'ssl_certfile': None,
                          'ssl_ca_certs': None,
                          'ssl_cert_reqs': 'required'}),
+    cfg.DictOpt('jobboard_redis_sentinel_ssl_options',
+                help='Redis sentinel ssl configuration options.',
+                default={'ssl': False,
+                         'ssl_keyfile': None,
+                         'ssl_certfile': None,
+                         'ssl_ca_certs': None,
+                         'ssl_cert_reqs': 'required'}),
     cfg.DictOpt('jobboard_zookeeper_ssl_options',
                 help='Zookeeper jobboard backend ssl configuration options.',
                 default={'use_ssl': False,
@@ -967,7 +961,7 @@ def handle_neutron_deprecations():
 def init(args, **kwargs):
     register_cli_opts()
     cfg.CONF(args=args, project='octavia',
-             version='%%prog %s' % version.version_info.release_string(),
+             version=f'%prog {version.version_info.release_string()}',
              **kwargs)
     validate.check_default_tls_versions_min_conflict()
     setup_remote_debugger()
