@@ -22,28 +22,33 @@ Defined here so these can also be used at deeper levels than the API.
 import ipaddress
 import re
 
-import netaddr
 from oslo_config import cfg
-import rfc3986
+from rfc3986 import uri_reference
+from rfc3986 import validators
 from wsme import types as wtypes
 
 from octavia.common import constants
+from octavia.common import data_models
 from octavia.common import exceptions
 from octavia.common import utils
 from octavia.i18n import _
 
 CONF = cfg.CONF
+_ListenerPUT = 'octavia.api.v2.types.listener.ListenerPUT'
 
 
 def url(url, require_scheme=True):
     """Raises an error if the url doesn't look like a URL."""
+    validator = validators.Validator()
+    if require_scheme:
+        validator.allow_schemes('http', 'https')
+        validator.require_presence_of('scheme', 'host')
+        validator.check_validity_of('scheme', 'host', 'path')
+    else:
+        validator.check_validity_of('path')
+
     try:
-        if not rfc3986.is_valid_uri(url, require_scheme=require_scheme):
-            raise exceptions.InvalidURL(url=url)
-        p_url = rfc3986.urlparse(rfc3986.normalize_uri(url))
-        if require_scheme:
-            if p_url.scheme not in ('http', 'https'):
-                raise exceptions.InvalidURL(url=url)
+        validator.validate(uri_reference(url))
     except Exception as e:
         raise exceptions.InvalidURL(url=url) from e
     return True
@@ -51,8 +56,10 @@ def url(url, require_scheme=True):
 
 def url_path(url_path):
     """Raises an error if the url_path doesn't look like a URL Path."""
+    validator = validators.Validator().check_validity_of('path')
     try:
-        p_url = rfc3986.urlparse(rfc3986.normalize_uri(url_path))
+        p_url = uri_reference(url_path)
+        validator.validate(p_url)
 
         invalid_path = (
             re.search(r"\s", url_path) or
@@ -191,26 +198,22 @@ def validate_l7rule_ssl_types(l7rule):
         # key and value are not allowed
         if req_key:
             # log error or raise
-            msg = 'L7rule type {0} does not use the "key" field.'.format(
-                rule_type)
+            msg = f'L7rule type {rule_type} does not use the "key" field.'
         elif req_value.lower() != 'true':
-            msg = 'L7rule value {0} is not a boolean True string.'.format(
-                req_value)
+            msg = f'L7rule value {req_value} is not a boolean True string.'
         elif compare_type != constants.L7RULE_COMPARE_TYPE_EQUAL_TO:
-            msg = 'L7rule type {0} only supports the {1} compare type.'.format(
+            msg = 'L7rule type {} only supports the {} compare type.'.format(
                 rule_type, constants.L7RULE_COMPARE_TYPE_EQUAL_TO)
 
     if rule_type == constants.L7RULE_TYPE_SSL_VERIFY_RESULT:
         if req_key:
             # log or raise req_key not used
-            msg = 'L7rule type {0} does not use the "key" field.'.format(
-                rule_type)
+            msg = f'L7rule type {rule_type} does not use the "key" field.'
         elif not req_value.isdigit() or int(req_value) < 0:
             # log or raise req_value must be int
-            msg = 'L7rule type {0} needs a int value, which is >= 0'.format(
-                rule_type)
+            msg = f'L7rule type {rule_type} needs a int value, which is >= 0'
         elif compare_type != constants.L7RULE_COMPARE_TYPE_EQUAL_TO:
-            msg = 'L7rule type {0} only supports the {1} compare type.'.format(
+            msg = 'L7rule type {} only supports the {} compare type.'.format(
                 rule_type, constants.L7RULE_COMPARE_TYPE_EQUAL_TO)
 
     if rule_type == constants.L7RULE_TYPE_SSL_DN_FIELD:
@@ -220,11 +223,11 @@ def validate_l7rule_ssl_types(l7rule):
 
         if not req_key or not req_value:
             # log or raise key and value must be specified.
-            msg = 'L7rule type {0} needs to specify a key and a value.'.format(
-                rule_type)
+            msg = (f'L7rule type {rule_type} needs to specify a '
+                   f'key and a value.')
         # log or raise the key must be splited by '-'
         elif not dn_regex.match(req_key):
-            msg = ('Invalid L7rule distinguished name field.')
+            msg = 'Invalid L7rule distinguished name field.'
 
     if msg:
         raise exceptions.InvalidL7Rule(msg=msg)
@@ -239,7 +242,7 @@ def sanitize_l7policy_api_args(l7policy, create=False):
     redirect_pool_id exists in the database, but will raise an
     error if a redirect_url doesn't look like a URL.
 
-    :param l7policy: The L7 Policy dictionary we are santizing / validating
+    :param l7policy: The L7 Policy dictionary we are sanitizing / validating
     """
     if 'action' in l7policy.keys():
         if l7policy['action'] == constants.L7POLICY_ACTION_REJECT:
@@ -391,7 +394,7 @@ def network_allowed_by_config(network_id, valid_networks=None):
 
 
 def is_ip_member_of_cidr(address, cidr):
-    if netaddr.IPAddress(address) in netaddr.IPNetwork(cidr):
+    if ipaddress.ip_address(address) in ipaddress.ip_network(cidr):
         return True
     return False
 
@@ -526,3 +529,36 @@ def check_alpn_protocols(protocols):
     if invalid_protocols:
         raise exceptions.ValidationException(
             detail=_('Invalid ALPN protocol: ' + ', '.join(invalid_protocols)))
+
+
+def check_hsts_options(listener: dict):
+    if ((listener.get('hsts_include_subdomains') or
+         listener.get('hsts_preload')) and
+            not isinstance(listener.get('hsts_max_age'), int)):
+        raise exceptions.ValidationException(
+            detail=_('HSTS configuration options hsts_include_subdomains and '
+                     'hsts_preload only make sense if hsts_max_age is '
+                     'set as well.'))
+
+    if (isinstance(listener.get('hsts_max_age'), int) and
+            listener['protocol'] != constants.PROTOCOL_TERMINATED_HTTPS):
+        raise exceptions.ValidationException(
+            detail=_('The HSTS feature can only be used for listeners using '
+                     'the TERMINATED_HTTPS protocol.'))
+
+
+def check_hsts_options_put(listener: _ListenerPUT,
+                           db_listener: data_models.Listener):
+    hsts_disabled = all(obj.hsts_max_age in [None, wtypes.Unset] for obj
+                        in (db_listener, listener))
+    if ((listener.hsts_include_subdomains or listener.hsts_preload) and
+            hsts_disabled):
+        raise exceptions.ValidationException(
+            detail=_('Cannot enable hsts_include_subdomains or hsts_preload '
+                     'if hsts_max_age was not set as well.'))
+
+    if (isinstance(listener.hsts_max_age, int) and
+            db_listener.protocol != constants.PROTOCOL_TERMINATED_HTTPS):
+        raise exceptions.ValidationException(
+            detail=_('The HSTS feature can only be used for listeners using '
+                     'the TERMINATED_HTTPS protocol.'))
