@@ -194,13 +194,12 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
             # Don't remove egress rules and don't confuse other protocols with
             # None ports with the egress rules.  VRRP uses protocol 51 and 112
             if (rule.get('direction') == 'egress' or
-                    rule.get('protocol') is None or
-                    rule['protocol'].upper() not in
+                    rule.get('protocol').upper() not in
                     [constants.PROTOCOL_TCP, constants.PROTOCOL_UDP,
                      lib_consts.PROTOCOL_SCTP]):
                 continue
             old_ports.append((rule.get('port_range_max'),
-                              rule['protocol'].lower(),
+                              rule.get('protocol').lower(),
                               rule.get('remote_ip_prefix')))
 
         add_ports = set(updated_ports) - set(old_ports)
@@ -476,7 +475,9 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
         :param load_balancer: octavia.common.data_models.LoadBalancer instance
         :return: octavia.common.data_models.Vip,
                  list(octavia.common.data_models.AdditionalVip)
-        :raises: AllocateVIPException, PortNotFound, SubnetNotFound
+        :raises AllocateVIPException: generic error allocating the VIP
+        :raises PortNotFound: port was not found
+        :raises SubnetNotFound: subnet was not found
         """
         if load_balancer.vip.port_id:
             try:
@@ -501,7 +502,7 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
                     self.delete_port(load_balancer.vip.port_id)
                 else:
                     raise base.AllocateVIPException(
-                        'VIP port {0} is broken, but is owned by project {1} '
+                        'VIP port {} is broken, but is owned by project {} '
                         'so will not be recreated. Aborting VIP allocation.'
                         .format(port.id, port.project_id))
             except base.AllocateVIPException as e:
@@ -553,7 +554,7 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
             constants.NAME: 'octavia-lb-' + load_balancer.id,
             constants.NETWORK_ID: load_balancer.vip.network_id,
             constants.ADMIN_STATE_UP: False,
-            'device_id': 'lb-{0}'.format(load_balancer.id),
+            'device_id': f'lb-{load_balancer.id}',
             constants.DEVICE_OWNER: constants.OCTAVIA_OWNER,
             project_id_key: load_balancer.project_id}
 
@@ -616,8 +617,8 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
         try:
             subnet = self.get_subnet(vip.subnet_id)
         except base.SubnetNotFound as e:
-            msg = ("Can't unplug vip because vip subnet {0} was not "
-                   "found").format(vip.subnet_id)
+            msg = (f"Can't unplug vip because vip subnet {vip.subnet_id} "
+                   f"was not found")
             LOG.exception(msg)
             raise base.PluggedVIPNotFound(msg) from e
         for amphora in filter(
@@ -638,8 +639,8 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
         except Exception as e:
             message = _('Error plugging amphora (compute_id: {compute_id}) '
                         'into network {network_id}.').format(
-                            compute_id=compute_id,
-                            network_id=network_id)
+                compute_id=compute_id,
+                network_id=network_id)
             LOG.exception(message)
             raise base.PlugNetworkException(message) from e
 
@@ -648,8 +649,8 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
     def unplug_network(self, compute_id, network_id):
         interfaces = self.get_plugged_networks(compute_id)
         if not interfaces:
-            msg = ('Amphora with compute id {compute_id} does not have any '
-                   'plugged networks').format(compute_id=compute_id)
+            msg = (f'Amphora with compute id {compute_id} does not have any '
+                   f'plugged networks')
             raise base.NetworkNotFound(msg)
 
         unpluggers = self._get_interfaces_to_unplug(interfaces, network_id)
