@@ -76,7 +76,7 @@ class TestL7Policy(base.BaseAPITest):
                 'is_admin_project': True,
                 'service_project_domain_id': None,
                 'service_project_id': None,
-                'roles': ['load-balancer_member'],
+                'roles': ['load-balancer_member', 'member'],
                 'user_id': None,
                 'is_admin': False,
                 'service_user_domain_id': None,
@@ -209,7 +209,7 @@ class TestL7Policy(base.BaseAPITest):
                 'is_admin_project': True,
                 'service_project_domain_id': None,
                 'service_project_id': None,
-                'roles': ['load-balancer_member'],
+                'roles': ['load-balancer_member', 'member'],
                 'user_id': None,
                 'is_admin': False,
                 'service_user_domain_id': None,
@@ -523,9 +523,9 @@ class TestL7Policy(base.BaseAPITest):
         l7pos = self.get(self.L7POLICIES_PATH, params={
             'fields': ['id', 'project_id']}).json
         for l7po in l7pos['l7policies']:
-            self.assertIn(u'id', l7po)
-            self.assertIn(u'project_id', l7po)
-            self.assertNotIn(u'description', l7po)
+            self.assertIn('id', l7po)
+            self.assertIn('project_id', l7po)
+            self.assertNotIn('description', l7po)
 
     def test_get_one_fields_filter(self):
         l7p1 = self.create_l7policy(
@@ -536,9 +536,9 @@ class TestL7Policy(base.BaseAPITest):
         l7po = self.get(
             self.L7POLICY_PATH.format(l7policy_id=l7p1.get('id')),
             params={'fields': ['id', 'project_id']}).json.get(self.root_tag)
-        self.assertIn(u'id', l7po)
-        self.assertIn(u'project_id', l7po)
-        self.assertNotIn(u'description', l7po)
+        self.assertIn('id', l7po)
+        self.assertIn('project_id', l7po)
+        self.assertNotIn('description', l7po)
 
     def test_get_all_filter(self):
         policy1 = self.create_l7policy(
@@ -685,7 +685,7 @@ class TestL7Policy(base.BaseAPITest):
                 'is_admin_project': True,
                 'service_project_domain_id': None,
                 'service_project_id': None,
-                'roles': ['load-balancer_member'],
+                'roles': ['load-balancer_member', 'member'],
                 'user_id': None,
                 'is_admin': False,
                 'service_user_domain_id': None,
@@ -919,7 +919,7 @@ class TestL7Policy(base.BaseAPITest):
                 'is_admin_project': True,
                 'service_project_domain_id': None,
                 'service_project_id': None,
-                'roles': ['load-balancer_member'],
+                'roles': ['load-balancer_member', 'member'],
                 'user_id': None,
                 'is_admin': False,
                 'service_user_domain_id': None,
@@ -1165,7 +1165,7 @@ class TestL7Policy(base.BaseAPITest):
                 'is_admin_project': True,
                 'service_project_domain_id': None,
                 'service_project_id': None,
-                'roles': ['load-balancer_member'],
+                'roles': ['load-balancer_member', 'member'],
                 'user_id': None,
                 'is_admin': False,
                 'service_user_domain_id': None,
