@@ -51,31 +51,11 @@ class TestUtil(base.TestCase):
         self.assertEqual(fake_path, result)
 
     def test_keepalived_lvs_init_path(self):
-        # Test systemd
         ref_path = (consts.SYSTEMD_DIR + '/' +
-                    consts.KEEPALIVED_SYSTEMD_PREFIX % str(self.listener_id))
-        result = util.keepalived_lvs_init_path(consts.INIT_SYSTEMD,
-                                               self.listener_id)
+                    consts.KEEPALIVEDLVS_SYSTEMD % self.listener_id)
+        result = util.keepalived_lvs_init_path(self.listener_id)
         self.assertEqual(ref_path, result)
 
-        # Test upstart
-        ref_path = (consts.UPSTART_DIR + '/' +
-                    consts.KEEPALIVED_UPSTART_PREFIX % str(self.listener_id))
-        result = util.keepalived_lvs_init_path(consts.INIT_UPSTART,
-                                               self.listener_id)
-        self.assertEqual(ref_path, result)
-
-        # Test sysvinit
-        ref_path = (consts.SYSVINIT_DIR + '/' +
-                    consts.KEEPALIVED_SYSVINIT_PREFIX % str(self.listener_id))
-        result = util.keepalived_lvs_init_path(consts.INIT_SYSVINIT,
-                                               self.listener_id)
-        self.assertEqual(ref_path, result)
-
-        # Test bad init system
-        self.assertRaises(util.UnknownInitError, util.keepalived_lvs_init_path,
-                          'bogus_init', self.listener_id)
-
     def test_keepalived_lvs_pids_path(self):
         fake_path = '/fake/path'
         self.CONF.config(group="haproxy_amphora", base_path=fake_path)
@@ -162,11 +142,17 @@ class TestUtil(base.TestCase):
 
         util.run_systemctl_command('test', 'world')
         mock_check_output.assert_called_once_with(
-            ['systemctl', 'test', 'world'], stderr=subprocess.STDOUT)
+            ['systemctl', 'test', 'world'], stderr=subprocess.STDOUT,
+            encoding='utf-8')
 
         mock_check_output.side_effect = subprocess.CalledProcessError(1,
                                                                       'boom')
-        util.run_systemctl_command('test', 'world')
+        self.assertRaises(subprocess.CalledProcessError,
+                          util.run_systemctl_command, 'test', 'world')
+
+        mock_check_output.side_effect = subprocess.CalledProcessError(1,
+                                                                      'boom')
+        util.run_systemctl_command('test', 'world', False)
 
     @mock.patch('octavia.amphorae.backends.agent.api_server.util.config_path')
     @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
@@ -275,7 +261,7 @@ class TestUtil(base.TestCase):
             pass
 
         # Bad listener mode
-        fake_cfg = 'stats socket foo\nfrontend {}\nmode\n'.format(LISTENER_ID1)
+        fake_cfg = f'stats socket foo\nfrontend {LISTENER_ID1}\nmode\n'
         self.useFixture(test_utils.OpenFixture(path, fake_cfg))
         self.assertRaises(util.ParsingError, util.parse_haproxy_file,
                           LISTENER_ID1)
@@ -370,57 +356,13 @@ class TestUtil(base.TestCase):
         self.assertEqual([], util.get_haproxy_vip_addresses(LB_ID1))
         mock_cfg_path.assert_called_once_with(LB_ID1)
 
-    @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
-                'keepalived_lvs_cfg_path')
-    def test_get_lvs_vip_addresses(self, mock_cfg_path):
-        FAKE_PATH = 'fake_path'
-        mock_cfg_path.return_value = FAKE_PATH
-        self.useFixture(
-            test_utils.OpenFixture(FAKE_PATH, 'no match')).mock_open()
-
-        # Test with no matching lines in the config file
-        self.assertEqual([], util.get_lvs_vip_addresses(LB_ID1))
-        mock_cfg_path.assert_called_once_with(LB_ID1)
-
-        # Test with 2 matching lines
-        mock_cfg_path.reset_mock()
-        test_data = ('virtual_server_group ipv4-group {\n'
-                     '    203.0.113.43 1\n'
-                     '    203.0.113.44 1\n'
-                     '}\n')
-        self.useFixture(
-            test_utils.OpenFixture(FAKE_PATH, test_data)).mock_open()
-        expected_result = ['203.0.113.43', '203.0.113.44']
-        self.assertEqual(expected_result,
-                         util.get_lvs_vip_addresses(LB_ID1))
-        mock_cfg_path.assert_called_once_with(LB_ID1)
-
-        # Test with 2 groups
-        mock_cfg_path.reset_mock()
-        test_data = ('virtual_server_group ipv4-group {\n'
-                     '    203.0.113.43 1\n'
-                     '}\n'
-                     'virtual_server_group ipv6-group {\n'
-                     '    2d01:27::1 2\n'
-                     '    2d01:27::2 2\n'
-                     '}\n')
-        self.useFixture(
-            test_utils.OpenFixture(FAKE_PATH, test_data)).mock_open()
-        expected_result = ['203.0.113.43', '2d01:27::1', '2d01:27::2']
-        self.assertEqual(expected_result,
-                         util.get_lvs_vip_addresses(LB_ID1))
-        mock_cfg_path.assert_called_once_with(LB_ID1)
-
     @mock.patch('octavia.amphorae.backends.utils.ip_advertisement.'
                 'send_ip_advertisement')
     @mock.patch('octavia.amphorae.backends.utils.network_utils.'
                 'get_interface_name')
     @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
                 'get_haproxy_vip_addresses')
-    @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
-                'get_lvs_vip_addresses')
-    def test_send_vip_advertisements(self, mock_get_lvs_vip_addrs,
-                                     mock_get_vip_addrs,
+    def test_send_vip_advertisements(self, mock_get_vip_addrs,
                                      mock_get_int_name, mock_send_advert):
         mock_get_vip_addrs.side_effect = [[], ['203.0.113.46'],
                                           Exception('boom')]
@@ -429,7 +371,6 @@ class TestUtil(base.TestCase):
         # Test no VIPs
         util.send_vip_advertisements(LB_ID1)
         mock_get_vip_addrs.assert_called_once_with(LB_ID1)
-        mock_get_lvs_vip_addrs.assert_not_called()
         mock_get_int_name.assert_not_called()
         mock_send_advert.assert_not_called()
 
@@ -439,7 +380,6 @@ class TestUtil(base.TestCase):
         mock_send_advert.reset_mock()
         util.send_vip_advertisements(LB_ID1)
         mock_get_vip_addrs.assert_called_once_with(LB_ID1)
-        mock_get_lvs_vip_addrs.assert_not_called()
         mock_get_int_name.assert_called_once_with(
             '203.0.113.46', net_ns=consts.AMPHORA_NAMESPACE)
         mock_send_advert.assert_called_once_with(
@@ -453,48 +393,6 @@ class TestUtil(base.TestCase):
         mock_get_int_name.assert_not_called()
         mock_send_advert.assert_not_called()
 
-    @mock.patch('octavia.amphorae.backends.utils.ip_advertisement.'
-                'send_ip_advertisement')
-    @mock.patch('octavia.amphorae.backends.utils.network_utils.'
-                'get_interface_name')
-    @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
-                'get_haproxy_vip_addresses')
-    @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
-                'get_lvs_vip_addresses')
-    def test_send_vip_advertisements_udp(self, mock_get_lvs_vip_addrs,
-                                         mock_get_vip_addrs,
-                                         mock_get_int_name, mock_send_advert):
-        mock_get_lvs_vip_addrs.side_effect = [[], ['203.0.113.46'],
-                                              Exception('boom')]
-        mock_get_int_name.return_value = 'fake0'
-
-        # Test no VIPs
-        util.send_vip_advertisements(listener_id=LISTENER_ID1)
-        mock_get_lvs_vip_addrs.assert_called_once_with(LISTENER_ID1)
-        mock_get_vip_addrs.assert_not_called()
-        mock_get_int_name.assert_not_called()
-        mock_send_advert.assert_not_called()
-
-        # Test with a VIP
-        mock_get_lvs_vip_addrs.reset_mock()
-        mock_get_int_name.reset_mock()
-        mock_send_advert.reset_mock()
-        util.send_vip_advertisements(listener_id=LISTENER_ID1)
-        mock_get_lvs_vip_addrs.assert_called_once_with(LISTENER_ID1)
-        mock_get_vip_addrs.assert_not_called()
-        mock_get_int_name.assert_called_once_with(
-            '203.0.113.46', net_ns=consts.AMPHORA_NAMESPACE)
-        mock_send_advert.assert_called_once_with(
-            'fake0', '203.0.113.46', net_ns=consts.AMPHORA_NAMESPACE)
-
-        # Test with an exception (should not raise)
-        mock_get_lvs_vip_addrs.reset_mock()
-        mock_get_int_name.reset_mock()
-        mock_send_advert.reset_mock()
-        util.send_vip_advertisements(listener_id=LISTENER_ID1)
-        mock_get_int_name.assert_not_called()
-        mock_send_advert.assert_not_called()
-
     @mock.patch('octavia.amphorae.backends.utils.ip_advertisement.'
                 'send_ip_advertisement')
     @mock.patch('octavia.amphorae.backends.utils.network_utils.'
