@@ -70,7 +70,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
             'api_version': API_VERSION}
         self.driver.clients[
             API_VERSION].get_info.return_value = {
-            'haproxy_version': u'1.6.3-1ubuntu0.1',
+            'haproxy_version': '1.6.3-1ubuntu0.1',
             'api_version': API_VERSION}
         self.driver.jinja_combo = mock.MagicMock()
         self.driver.lvs_jinja = mock.MagicMock()
@@ -356,7 +356,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         self.driver.cert_manager.get_secret.return_value = fake_secret
         ref_md5 = md5(fake_secret, usedforsecurity=False).hexdigest()  # nosec
         ref_id = hashlib.sha1(fake_secret).hexdigest()  # nosec
-        ref_name = '{id}.pem'.format(id=ref_id)
+        ref_name = f'{ref_id}.pem'
 
         result = self.driver._process_secret(
             sample_listener, sample_listener.client_ca_tls_certificate_id,
@@ -419,10 +419,9 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         fake_pem = b'fake pem'
         mock_build_pem.return_value = fake_pem
         ref_md5 = md5(fake_pem, usedforsecurity=False).hexdigest()  # nosec
-        ref_name = '{id}.pem'.format(id=pool_cert.id)
-        ref_path = '{cert_dir}/{lb_id}/{name}'.format(
-            cert_dir=fake_cert_dir, lb_id=sample_listener.load_balancer.id,
-            name=ref_name)
+        ref_name = f'{pool_cert.id}.pem'
+        ref_path = (f'{fake_cert_dir}/{sample_listener.load_balancer.id}/'
+                    f'{ref_name}')
         ref_ca_name = 'fake_ca.pem'
         ref_ca_path = '{cert_dir}/{lb_id}/{name}'.format(
             cert_dir=fake_cert_dir, lb_id=sample_listener.load_balancer.id,
@@ -637,7 +636,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
             # Ensure that at least one call in each pair has been seen
             if (dcp_calls[0] not in mock_calls and
                     dcp_calls[1] not in mock_calls):
-                raise Exception("%s not found in %s" % (dcp_calls, mock_calls))
+                raise Exception(f"{dcp_calls} not found in {mock_calls}")
 
         # Now just make sure we did an update and not a delete
         self.driver.clients[API_VERSION].delete_listener.assert_not_called()
@@ -951,7 +950,7 @@ class TestAmphoraAPIClientTest(base.TestCase):
     @requests_mock.mock()
     def test_get_api_version(self, mock_requests):
         ref_api_version = {'api_version': '0.1'}
-        mock_requests.get('{base}/'.format(base=self.base_url),
+        mock_requests.get(f'{self.base_url}/',
                           json=ref_api_version)
         result = self.driver.get_api_version(self.amp)
         self.assertEqual(ref_api_version, result)
@@ -960,7 +959,7 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_get_info(self, m):
         info = {"hostname": "some_hostname", "version": "some_version",
                 "api_version": "1.0", "uuid": FAKE_UUID_1}
-        m.get("{base}/info".format(base=self.base_url_ver),
+        m.get(f"{self.base_url_ver}/info",
               json=info)
         information = self.driver.get_info(self.amp)
         self.assertEqual(info, information)
@@ -969,7 +968,7 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_get_info_with_timeout_dict(self, m):
         info = {"hostname": "some_hostname", "version": "some_version",
                 "api_version": "1.0", "uuid": FAKE_UUID_1}
-        m.get("{base}/info".format(base=self.base_url_ver),
+        m.get(f"{self.base_url_ver}/info",
               json=info)
         timeout_dict = {
             constants.CONN_MAX_RETRIES: 100,
@@ -980,27 +979,27 @@ class TestAmphoraAPIClientTest(base.TestCase):
 
     @requests_mock.mock()
     def test_get_info_unauthorized(self, m):
-        m.get("{base}/info".format(base=self.base_url_ver),
+        m.get(f"{self.base_url_ver}/info",
               status_code=401)
         self.assertRaises(exc.Unauthorized, self.driver.get_info, self.amp)
 
     @requests_mock.mock()
     def test_get_info_missing(self, m):
-        m.get("{base}/info".format(base=self.base_url_ver),
+        m.get(f"{self.base_url_ver}/info",
               status_code=404,
               headers={'content-type': 'application/json'})
         self.assertRaises(exc.NotFound, self.driver.get_info, self.amp)
 
     @requests_mock.mock()
     def test_get_info_server_error(self, m):
-        m.get("{base}/info".format(base=self.base_url_ver),
+        m.get(f"{self.base_url_ver}/info",
               status_code=500)
         self.assertRaises(exc.InternalServerError, self.driver.get_info,
                           self.amp)
 
     @requests_mock.mock()
     def test_get_info_service_unavailable(self, m):
-        m.get("{base}/info".format(base=self.base_url_ver),
+        m.get(f"{self.base_url_ver}/info",
               status_code=503)
         self.assertRaises(exc.ServiceUnavailable, self.driver.get_info,
                           self.amp)
@@ -1011,34 +1010,34 @@ class TestAmphoraAPIClientTest(base.TestCase):
                    "api_version": "1.0", "uuid": FAKE_UUID_1,
                    "network_tx": "some_tx", "network_rx": "some_rx",
                    "active": True, "haproxy_count": 10}
-        m.get("{base}/details".format(base=self.base_url_ver),
+        m.get(f"{self.base_url_ver}/details",
               json=details)
         amp_details = self.driver.get_details(self.amp)
         self.assertEqual(details, amp_details)
 
     @requests_mock.mock()
     def test_get_details_unauthorized(self, m):
-        m.get("{base}/details".format(base=self.base_url_ver),
+        m.get(f"{self.base_url_ver}/details",
               status_code=401)
         self.assertRaises(exc.Unauthorized, self.driver.get_details, self.amp)
 
     @requests_mock.mock()
     def test_get_details_missing(self, m):
-        m.get("{base}/details".format(base=self.base_url_ver),
+        m.get(f"{self.base_url_ver}/details",
               status_code=404,
               headers={'content-type': 'application/json'})
         self.assertRaises(exc.NotFound, self.driver.get_details, self.amp)
 
     @requests_mock.mock()
     def test_get_details_server_error(self, m):
-        m.get("{base}/details".format(base=self.base_url_ver),
+        m.get(f"{self.base_url_ver}/details",
               status_code=500)
         self.assertRaises(exc.InternalServerError, self.driver.get_details,
                           self.amp)
 
     @requests_mock.mock()
     def test_get_details_service_unavailable(self, m):
-        m.get("{base}/details".format(base=self.base_url_ver),
+        m.get(f"{self.base_url_ver}/details",
               status_code=503)
         self.assertRaises(exc.ServiceUnavailable, self.driver.get_details,
                           self.amp)
@@ -1047,21 +1046,21 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_get_all_listeners(self, m):
         listeners = [{"status": "ONLINE", "provisioning_status": "ACTIVE",
                       "type": "PASSIVE", "uuid": FAKE_UUID_1}]
-        m.get("{base}/listeners".format(base=self.base_url_ver),
+        m.get(f"{self.base_url_ver}/listeners",
               json=listeners)
         all_listeners = self.driver.get_all_listeners(self.amp)
         self.assertEqual(listeners, all_listeners)
 
     @requests_mock.mock()
     def test_get_all_listeners_unauthorized(self, m):
-        m.get("{base}/listeners".format(base=self.base_url_ver),
+        m.get(f"{self.base_url_ver}/listeners",
               status_code=401)
         self.assertRaises(exc.Unauthorized, self.driver.get_all_listeners,
                           self.amp)
 
     @requests_mock.mock()
     def test_get_all_listeners_missing(self, m):
-        m.get("{base}/listeners".format(base=self.base_url_ver),
+        m.get(f"{self.base_url_ver}/listeners",
               status_code=404,
               headers={'content-type': 'application/json'})
         self.assertRaises(exc.NotFound, self.driver.get_all_listeners,
@@ -1069,95 +1068,85 @@ class TestAmphoraAPIClientTest(base.TestCase):
 
     @requests_mock.mock()
     def test_get_all_listeners_server_error(self, m):
-        m.get("{base}/listeners".format(base=self.base_url_ver),
+        m.get(f"{self.base_url_ver}/listeners",
               status_code=500)
         self.assertRaises(exc.InternalServerError,
                           self.driver.get_all_listeners, self.amp)
 
     @requests_mock.mock()
     def test_get_all_listeners_service_unavailable(self, m):
-        m.get("{base}/listeners".format(base=self.base_url_ver),
+        m.get(f"{self.base_url_ver}/listeners",
               status_code=503)
         self.assertRaises(exc.ServiceUnavailable,
                           self.driver.get_all_listeners, self.amp)
 
     @requests_mock.mock()
     def test_start_loadbalancer(self, m):
-        m.put("{base}/loadbalancer/{loadbalancer_id}/start".format(
-            base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1))
+        m.put(f"{self.base_url_ver}/loadbalancer/{FAKE_UUID_1}/start")
         self.driver.start_listener(self.amp, FAKE_UUID_1)
         self.assertTrue(m.called)
 
     @requests_mock.mock()
     def test_start_loadbalancer_missing(self, m):
-        m.put("{base}/loadbalancer/{loadbalancer_id}/start".format(
-            base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1),
-            status_code=404,
-            headers={'content-type': 'application/json'})
+        m.put(f"{self.base_url_ver}/loadbalancer/{FAKE_UUID_1}/start",
+              status_code=404,
+              headers={'content-type': 'application/json'})
         self.assertRaises(exc.NotFound, self.driver.start_listener,
                           self.amp, FAKE_UUID_1)
 
     @requests_mock.mock()
     def test_start_loadbalancer_unauthorized(self, m):
-        m.put("{base}/loadbalancer/{loadbalancer_id}/start".format(
-            base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1),
-            status_code=401)
+        m.put(f"{self.base_url_ver}/loadbalancer/{FAKE_UUID_1}/start",
+              status_code=401)
         self.assertRaises(exc.Unauthorized, self.driver.start_listener,
                           self.amp, FAKE_UUID_1)
 
     @requests_mock.mock()
     def test_start_loadbalancer_server_error(self, m):
-        m.put("{base}/loadbalancer/{loadbalancer_id}/start".format(
-            base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1),
-            status_code=500)
+        m.put(f"{self.base_url_ver}/loadbalancer/{FAKE_UUID_1}/start",
+              status_code=500)
         self.assertRaises(exc.InternalServerError, self.driver.start_listener,
                           self.amp, FAKE_UUID_1)
 
     @requests_mock.mock()
     def test_start_loadbalancer_service_unavailable(self, m):
-        m.put("{base}/loadbalancer/{loadbalancer_id}/start".format(
-            base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1),
-            status_code=503)
+        m.put(f"{self.base_url_ver}/loadbalancer/{FAKE_UUID_1}/start",
+              status_code=503)
         self.assertRaises(exc.ServiceUnavailable, self.driver.start_listener,
                           self.amp, FAKE_UUID_1)
 
     @requests_mock.mock()
     def test_delete_listener(self, m):
-        m.delete("{base}/listeners/{listener_id}".format(
-            base=self.base_url_ver, listener_id=FAKE_UUID_1), json={})
+        m.delete(f"{self.base_url_ver}/listeners/{FAKE_UUID_1}", json={})
         self.driver.delete_listener(self.amp, FAKE_UUID_1)
         self.assertTrue(m.called)
 
     @requests_mock.mock()
     def test_delete_listener_missing(self, m):
-        m.delete("{base}/listeners/{listener_id}".format(
-            base=self.base_url_ver, listener_id=FAKE_UUID_1),
-            status_code=404,
-            headers={'content-type': 'application/json'})
+        m.delete(f"{self.base_url_ver}/listeners/{FAKE_UUID_1}",
+                 status_code=404,
+                 headers={'content-type': 'application/json'})
         self.driver.delete_listener(self.amp, FAKE_UUID_1)
         self.assertTrue(m.called)
 
     @requests_mock.mock()
     def test_delete_listener_unauthorized(self, m):
-        m.delete("{base}/listeners/{listener_id}".format(
-            base=self.base_url_ver, listener_id=FAKE_UUID_1),
-            status_code=401)
+        m.delete(f"{self.base_url_ver}/listeners/{FAKE_UUID_1}",
+                 status_code=401)
         self.assertRaises(exc.Unauthorized, self.driver.delete_listener,
                           self.amp, FAKE_UUID_1)
 
     @requests_mock.mock()
     def test_delete_listener_server_error(self, m):
-        m.delete("{base}/listeners/{listener_id}".format(
-            base=self.base_url_ver, listener_id=FAKE_UUID_1),
-            status_code=500)
+        m.delete(f"{self.base_url_ver}/listeners/{FAKE_UUID_1}",
+                 status_code=500)
         self.assertRaises(exc.InternalServerError, self.driver.delete_listener,
                           self.amp, FAKE_UUID_1)
 
     @requests_mock.mock()
     def test_delete_listener_service_unavailable(self, m):
-        m.delete("{base}/listeners/{listener_id}".format(
-            base=self.base_url_ver, listener_id=FAKE_UUID_1),
-            status_code=503)
+        m.delete(f"{self.base_url_ver}/listeners/{FAKE_UUID_1}",
+                 status_code=503)
         self.assertRaises(exc.ServiceUnavailable, self.driver.delete_listener,
                           self.amp, FAKE_UUID_1)
 
@@ -1214,14 +1203,14 @@ class TestAmphoraAPIClientTest(base.TestCase):
 
     @requests_mock.mock()
     def test_update_cert_for_rotation(self, m):
-        m.put("{base}/certificate".format(base=self.base_url_ver))
+        m.put(f"{self.base_url_ver}/certificate")
         resp_body = self.driver.update_cert_for_rotation(self.amp,
                                                          "some_file")
         self.assertEqual(200, resp_body.status_code)
 
     @requests_mock.mock()
     def test_update_invalid_cert_for_rotation(self, m):
-        m.put("{base}/certificate".format(base=self.base_url_ver),
+        m.put(f"{self.base_url_ver}/certificate",
               status_code=400)
         self.assertRaises(exc.InvalidRequest,
                           self.driver.update_cert_for_rotation, self.amp,
@@ -1229,7 +1218,7 @@ class TestAmphoraAPIClientTest(base.TestCase):
 
     @requests_mock.mock()
     def test_update_cert_for_rotation_unauthorized(self, m):
-        m.put("{base}/certificate".format(base=self.base_url_ver),
+        m.put(f"{self.base_url_ver}/certificate",
               status_code=401)
         self.assertRaises(exc.Unauthorized,
                           self.driver.update_cert_for_rotation, self.amp,
@@ -1237,7 +1226,7 @@ class TestAmphoraAPIClientTest(base.TestCase):
 
     @requests_mock.mock()
     def test_update_cert_for_rotation_error(self, m):
-        m.put("{base}/certificate".format(base=self.base_url_ver),
+        m.put(f"{self.base_url_ver}/certificate",
               status_code=500)
         self.assertRaises(exc.InternalServerError,
                           self.driver.update_cert_for_rotation, self.amp,
@@ -1245,7 +1234,7 @@ class TestAmphoraAPIClientTest(base.TestCase):
 
     @requests_mock.mock()
     def test_update_cert_for_rotation_unavailable(self, m):
-        m.put("{base}/certificate".format(base=self.base_url_ver),
+        m.put(f"{self.base_url_ver}/certificate",
               status_code=503)
         self.assertRaises(exc.ServiceUnavailable,
                           self.driver.update_cert_for_rotation, self.amp,
@@ -1356,10 +1345,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_upload_config(self, m):
         config = {"name": "fake_config"}
         m.put(
-            "{base}/loadbalancer/{"
-            "amphora_id}/{loadbalancer_id}/haproxy".format(
-                amphora_id=self.amp.id, base=self.base_url_ver,
-                loadbalancer_id=FAKE_UUID_1),
+            f"{self.base_url_ver}/loadbalancer/{self.amp.id}/"
+            f"{FAKE_UUID_1}/haproxy",
             json=config)
         self.driver.upload_config(self.amp, FAKE_UUID_1,
                                   config)
@@ -1369,10 +1356,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_upload_invalid_config(self, m):
         config = '{"name": "bad_config"}'
         m.put(
-            "{base}/loadbalancer/{"
-            "amphora_id}/{loadbalancer_id}/haproxy".format(
-                amphora_id=self.amp.id, base=self.base_url_ver,
-                loadbalancer_id=FAKE_UUID_1),
+            f"{self.base_url_ver}/loadbalancer/{self.amp.id}/"
+            f"{FAKE_UUID_1}/haproxy",
             status_code=400)
         self.assertRaises(exc.InvalidRequest, self.driver.upload_config,
                           self.amp, FAKE_UUID_1, config)
@@ -1381,10 +1366,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_upload_config_unauthorized(self, m):
         config = '{"name": "bad_config"}'
         m.put(
-            "{base}/loadbalancer/{"
-            "amphora_id}/{loadbalancer_id}/haproxy".format(
-                amphora_id=self.amp.id, base=self.base_url_ver,
-                loadbalancer_id=FAKE_UUID_1),
+            f"{self.base_url_ver}/loadbalancer/{self.amp.id}/"
+            f"{FAKE_UUID_1}/haproxy",
             status_code=401)
         self.assertRaises(exc.Unauthorized, self.driver.upload_config,
                           self.amp, FAKE_UUID_1, config)
@@ -1393,10 +1376,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_upload_config_server_error(self, m):
         config = '{"name": "bad_config"}'
         m.put(
-            "{base}/loadbalancer/{"
-            "amphora_id}/{loadbalancer_id}/haproxy".format(
-                amphora_id=self.amp.id, base=self.base_url_ver,
-                loadbalancer_id=FAKE_UUID_1),
+            f"{self.base_url_ver}/loadbalancer/{self.amp.id}/"
+            f"{FAKE_UUID_1}/haproxy",
             status_code=500)
         self.assertRaises(exc.InternalServerError, self.driver.upload_config,
                           self.amp, FAKE_UUID_1, config)
@@ -1405,10 +1386,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_upload_config_service_unavailable(self, m):
         config = '{"name": "bad_config"}'
         m.put(
-            "{base}/loadbalancer/{"
-            "amphora_id}/{loadbalancer_id}/haproxy".format(
-                amphora_id=self.amp.id, base=self.base_url_ver,
-                loadbalancer_id=FAKE_UUID_1),
+            f"{self.base_url_ver}/loadbalancer/{self.amp.id}/"
+            f"{FAKE_UUID_1}/haproxy",
             status_code=503)
         self.assertRaises(exc.ServiceUnavailable, self.driver.upload_config,
                           self.amp, FAKE_UUID_1, config)
@@ -1417,10 +1396,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_upload_udp_config(self, m):
         config = {"name": "fake_config"}
         m.put(
-            "{base}/listeners/"
-            "{amphora_id}/{listener_id}/udp_listener".format(
-                amphora_id=self.amp.id, base=self.base_url_ver,
-                listener_id=FAKE_UUID_1),
+            f"{self.base_url_ver}/listeners/{self.amp.id}/"
+            f"{FAKE_UUID_1}/udp_listener",
             json=config)
         self.driver.upload_udp_config(self.amp, FAKE_UUID_1, config)
         self.assertTrue(m.called)
@@ -1429,10 +1406,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_upload_udp_invalid_config(self, m):
         config = '{"name": "bad_config"}'
         m.put(
-            "{base}/listeners/"
-            "{amphora_id}/{listener_id}/udp_listener".format(
-                amphora_id=self.amp.id, base=self.base_url_ver,
-                listener_id=FAKE_UUID_1),
+            f"{self.base_url_ver}/listeners/{self.amp.id}/"
+            f"{FAKE_UUID_1}/udp_listener",
             status_code=400)
         self.assertRaises(exc.InvalidRequest, self.driver.upload_udp_config,
                           self.amp, FAKE_UUID_1, config)
@@ -1441,10 +1416,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_upload_udp_config_unauthorized(self, m):
         config = '{"name": "bad_config"}'
         m.put(
-            "{base}/listeners/"
-            "{amphora_id}/{listener_id}/udp_listener".format(
-                amphora_id=self.amp.id, base=self.base_url_ver,
-                listener_id=FAKE_UUID_1),
+            f"{self.base_url_ver}/listeners/{self.amp.id}/"
+            f"{FAKE_UUID_1}/udp_listener",
             status_code=401)
         self.assertRaises(exc.Unauthorized, self.driver.upload_udp_config,
                           self.amp, FAKE_UUID_1, config)
@@ -1453,10 +1426,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_upload_udp_config_server_error(self, m):
         config = '{"name": "bad_config"}'
         m.put(
-            "{base}/listeners/"
-            "{amphora_id}/{listener_id}/udp_listener".format(
-                amphora_id=self.amp.id, base=self.base_url_ver,
-                listener_id=FAKE_UUID_1),
+            f"{self.base_url_ver}/listeners/{self.amp.id}/"
+            f"{FAKE_UUID_1}/udp_listener",
             status_code=500)
         self.assertRaises(exc.InternalServerError,
                           self.driver.upload_udp_config,
@@ -1466,10 +1437,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_upload_udp_config_service_unavailable(self, m):
         config = '{"name": "bad_config"}'
         m.put(
-            "{base}/listeners/"
-            "{amphora_id}/{listener_id}/udp_listener".format(
-                amphora_id=self.amp.id, base=self.base_url_ver,
-                listener_id=FAKE_UUID_1),
+            f"{self.base_url_ver}/listeners/{self.amp.id}/"
+            f"{FAKE_UUID_1}/udp_listener",
             status_code=503)
         self.assertRaises(exc.ServiceUnavailable,
                           self.driver.upload_udp_config,
@@ -1477,18 +1446,14 @@ class TestAmphoraAPIClientTest(base.TestCase):
 
     @requests_mock.mock()
     def test_plug_vip(self, m):
-        m.post("{base}/plug/vip/{vip}".format(
-            base=self.base_url_ver, vip=FAKE_IP)
-        )
+        m.post(f"{self.base_url_ver}/plug/vip/{FAKE_IP}")
         self.driver.plug_vip(self.amp, FAKE_IP, self.subnet_info)
         self.assertTrue(m.called)
 
     @requests_mock.mock()
     def test_plug_vip_api_not_ready(self, m):
-        m.post("{base}/plug/vip/{vip}".format(
-            base=self.base_url_ver, vip=FAKE_IP),
-            status_code=404, headers={'content-type': 'text/html'}
-        )
+        m.post(f"{self.base_url_ver}/plug/vip/{FAKE_IP}",
+               status_code=404, headers={'content-type': 'text/html'})
         self.assertRaises(driver_except.TimeOutException,
                           self.driver.plug_vip,
                           self.amp, FAKE_IP, self.subnet_info)
@@ -1496,26 +1461,21 @@ class TestAmphoraAPIClientTest(base.TestCase):
 
     @requests_mock.mock()
     def test_plug_network(self, m):
-        m.post("{base}/plug/network".format(
-            base=self.base_url_ver)
-        )
+        m.post(f"{self.base_url_ver}/plug/network")
         self.driver.plug_network(self.amp, self.port_info)
         self.assertTrue(m.called)
 
     @requests_mock.mock()
     def test_upload_vrrp_config(self, m):
         config = '{"name": "bad_config"}'
-        m.put("{base}/vrrp/upload".format(
-            base=self.base_url_ver)
-        )
+        m.put(f"{self.base_url_ver}/vrrp/upload")
         self.driver.upload_vrrp_config(self.amp, config)
         self.assertTrue(m.called)
 
     @requests_mock.mock()
     def test_vrrp_action(self, m):
         action = 'start'
-        m.put("{base}/vrrp/{action}".format(base=self.base_url_ver,
-              action=action))
+        m.put(f"{self.base_url_ver}/vrrp/{action}")
         self.driver._vrrp_action(action, self.amp)
         self.assertTrue(m.called)
 
@@ -1523,8 +1483,7 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_get_interface(self, m):
         interface = [{"interface": "eth1"}]
         ip_addr = '192.51.100.1'
-        m.get("{base}/interface/{ip_addr}".format(base=self.base_url_ver,
-                                                  ip_addr=ip_addr),
+        m.get(f"{self.base_url_ver}/interface/{ip_addr}",
               json=interface)
         self.driver.get_interface(self.amp, ip_addr)
         self.assertTrue(m.called)
@@ -1538,13 +1497,13 @@ class TestAmphoraAPIClientTest(base.TestCase):
 
     @requests_mock.mock()
     def test_update_agent_config(self, m):
-        m.put("{base}/config".format(base=self.base_url_ver))
+        m.put(f"{self.base_url_ver}/config")
         resp_body = self.driver.update_agent_config(self.amp, "some_file")
         self.assertEqual(200, resp_body.status_code)
 
     @requests_mock.mock()
     def test_update_agent_config_error(self, m):
-        m.put("{base}/config".format(base=self.base_url_ver), status_code=500)
+        m.put(f"{self.base_url_ver}/config", status_code=500)
         self.assertRaises(exc.InternalServerError,
                           self.driver.update_agent_config, self.amp,
                           "some_file")
