@@ -11,10 +11,9 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
 import random
+from unittest import mock
 
-import mock
 from oslo_utils import uuidutils
 
 from octavia.common import constants
@@ -26,7 +25,7 @@ from octavia.tests.unit import base
 class TestStatsMixin(base.TestCase):
 
     def setUp(self):
-        super(TestStatsMixin, self).setUp()
+        super().setUp()
         self.sm = stats.StatsMixin()
 
         self.session = mock.MagicMock()
